%global b10includedir %{_includedir}/bind10
%global b10sysconfdir %{_sysconfdir}/bind10
%global b10libexecdir %{_libexecdir}/bind10
%global b10datadir %{_datadir}/bind10
%global b10localstatedir %{_localstatedir}/bind10
%global b10piddir /run/bind10

Name: bind10
Version: 1.0.0
Release: 4%{?dist}
Summary: The Berkeley Internet Name Domain 10 (BIND10) DNS and DHCP suite

License: ISC
URL: http://bind10.isc.org/wiki
Group: System Environment/Daemons

Source0: ftp://ftp.isc.org/isc/bind10/latest/%{name}-%{version}.tar.gz
Source1: bind10.service
Source2: bind10.tmpfiles.conf

Requires(pre): shadow-utils
Requires: systemd

BuildRequires: log4cplus-devel, python3-devel, botan-devel, boost-devel
BuildRequires: python3-setproctitle, sqlite-devel
BuildRequires: autoconf, automake, libtool
BuildRequires: systemd

Patch1: 0001-Make-Encode-Decode-Normalizer-compatible-with-boost-.patch

%description
BIND10 DNS and DHCP suite. This package contains binaries and utilities needed
by both DNS and DHCP services daemons. Make sure you install also bind10-dns or
bind10-dhcp packages.

%package devel
Summary: BIND10 suite libb10-dns++ development files
Group: Development/Libraries
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
BIND10 suite libb10-dns++ development files

%package libs
Summary: BIND10 suite libb10-dns++ library
Group: System Environment/Daemons

%description libs
BIND10 suite libb10-dns++ library

%package dns
Summary: BIND10 suite DNS service daemons
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description dns
BIND10 suite DNS service daemons

%package dhcp
Summary: BIND10 suite DHCP service daemons
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description dhcp
BIND10 suite DHCP service daemons

%prep
%setup -q

%patch1 -p1 -b .boost

%build
autoreconf -fiv
%configure \
  --without-werror \
  --disable-static \
  --disable-rpath

make V=1 %{?_smp_mflags}

%install
%make_install

for all in `find $RPM_BUILD_ROOT | grep '\.la$'`; do
  rm -f "$all"
done

# Those libs don't have development header files
for all in acl asiodns asiolink cache cc cfgclient datasrc dhcp++ dhcpsrv \
    dnsacl log nsas pydnspp resolve server-common threads util-io xfr; do
  rm -f $RPM_BUILD_ROOT/%{_libdir}/libb10-"$all".so
done

# Package those files via %%doc
rm -f $RPM_BUILD_ROOT/%{_docdir}/bind10/{AUTHORS,COPYING,ChangeLog,README}
rm -f $RPM_BUILD_ROOT/%{_docdir}/bind10/bind10*

mkdir -p $RPM_BUILD_ROOT/%{b10localstatedir}
chmod g+s $RPM_BUILD_ROOT/%{b10localstatedir}

mkdir -p ${RPM_BUILD_ROOT}%{_unitdir}
install -m 644 %{SOURCE1} ${RPM_BUILD_ROOT}%{_unitdir}/bind10.service

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/tmpfiles.d
install -m 644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/tmpfiles.d/bind10.conf

mkdir -p ${RPM_BUILD_ROOT}%{b10piddir}

%pre
if [ "$1" -eq 1 ]; then
  groupadd -g 25 -f -r named >/dev/null 2>&1 || :;
  useradd  -u 25 -r -N -M -g named -s /sbin/nologin -d /var/bind10 -c BIND10 named >/dev/null 2>&1 || :;
fi;
:;

%post
/sbin/ldconfig
%systemd_post bind10.service

%preun
%systemd_preun bind10.service

%postun
/sbin/ldconfig
%systemd_postun_with_restart bind10.service

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
 
%post dns -p /sbin/ldconfig
%postun dns -p /sbin/ldconfig

%post dhcp -p /sbin/ldconfig
%postun dhcp -p /sbin/ldconfig

%files
%doc ChangeLog README doc/guide/bind10-guide.css
%doc doc/guide/bind10-guide.html doc/guide/bind10-guide.txt
%doc doc/guide/bind10-messages.html

%{_libdir}/libb10-asiolink.so.*
%{_libdir}/libb10-cc.so.*
%{_libdir}/libb10-cfgclient.so.*
%{_libdir}/libb10-log.so.*
%{_libdir}/libb10-pydnspp.so.*
%{_libdir}/libb10-util-io.so.*
%{_libdir}/libb10-util.so.*

%dir %{b10datadir}
%{b10datadir}/*.zone
%{b10datadir}/*.tpl

%dir %{b10datadir}/config_plugins
%{b10datadir}/config_plugins/*

%{_sysconfdir}/tmpfiles.d/bind10.conf
%{_unitdir}/bind10.service
%attr(3775, root, named) %dir %{b10localstatedir}
%attr(-, named, named) %dir %{b10piddir}
%dir %{b10sysconfdir}
%config(noreplace) %{b10sysconfdir}/cmdctl*
%{_sbindir}/bind10
%{_mandir}/man8/bind10*
%{_bindir}/b10-certgen
%{_mandir}/man1/b10-certgen*
%{_bindir}/bindctl
%{_mandir}/man1/bindctl*
%{_bindir}/isc-sysinfo
%{_mandir}/man1/isc-sysinfo*
%{_sbindir}/b10-cmdctl-usermgr
%dir %{b10libexecdir}
%{b10libexecdir}/b10-cfgmgr
%{_mandir}/man8/b10-cfgmgr*
%{b10libexecdir}/b10-cmdctl
%{_mandir}/man8/b10-cmdctl*
%{b10libexecdir}/b10-init
%{_mandir}/man8/b10-init*
%{b10libexecdir}/b10-msgq
%{_mandir}/man8/b10-msgq*
%{b10libexecdir}/b10-sockcreator
%{_mandir}/man8/b10-sockcreator*
%{b10libexecdir}/b10-stats
%{_mandir}/man8/b10-stats*
%{b10libexecdir}/b10-stats-httpd
%{b10datadir}/init.spec
%{b10datadir}/cmdctl.spec
%{b10datadir}/msgq.spec
%{b10datadir}/stats.spec
%{b10datadir}/stats-httpd.spec

# Python stuff
%{python3_sitearch}/*.py*
%{python3_sitearch}/*.so
%{python3_sitearch}/__pycache__

%dir %{python3_sitearch}/isc/cc
%{python3_sitearch}/isc/cc/*.py*
%{python3_sitearch}/isc/cc/__pycache__

%dir %{python3_sitearch}/isc/util
%{python3_sitearch}/isc/util/*.py*
%{python3_sitearch}/isc/util/__pycache__

%dir %{python3_sitearch}/isc/net
%{python3_sitearch}/isc/net/*.py*
%{python3_sitearch}/isc/net/__pycache__

%dir %{python3_sitearch}/isc/log_messages
%{python3_sitearch}/isc/log_messages/*.py*
%{python3_sitearch}/isc/log_messages/__pycache__

%dir %{python3_sitearch}/isc/bind10
%{python3_sitearch}/isc/bind10/*.py*
%{python3_sitearch}/isc/bind10/__pycache__

%dir %{python3_sitearch}/bindctl
%{python3_sitearch}/bindctl/*.py*
%{python3_sitearch}/bindctl/__pycache__

%dir %{python3_sitearch}/isc/sysinfo
%{python3_sitearch}/isc/sysinfo/*.py*
%{python3_sitearch}/isc/sysinfo/__pycache__

%dir %{python3_sitearch}/isc/config
%{python3_sitearch}/isc/config/*.py*
%{python3_sitearch}/isc/config/__pycache__

%dir %{python3_sitearch}/isc/util/cio
%{python3_sitearch}/isc/util/cio/*.py*
%{python3_sitearch}/isc/util/cio/*.so
%{python3_sitearch}/isc/util/cio/__pycache__

%dir %{python3_sitearch}/isc/statistics
%{python3_sitearch}/isc/statistics/*.py*
%{python3_sitearch}/isc/statistics/__pycache__

%dir %{python3_sitearch}/isc
%{python3_sitearch}/isc/*.py*
%{python3_sitearch}/isc/*.so
%{python3_sitearch}/isc/__pycache__

%files devel
%dir %{b10includedir}
%dir %{b10includedir}/dns
%{b10includedir}/dns/*.h
%dir %{b10includedir}/exceptions
%{b10includedir}/exceptions/*.h
%dir %{b10includedir}/util
%{b10includedir}/util/*.h
%{_libdir}/libb10-cryptolink.so
%{_libdir}/libb10-dns++.so
%{_libdir}/libb10-exceptions.so
%{_libdir}/libb10-util.so
%{_libdir}/pkgconfig/dns++.pc

%files libs
%doc AUTHORS COPYING
%{_libdir}/libb10-cryptolink.so.*
%{_libdir}/libb10-dns++.so.*
%{_libdir}/libb10-exceptions.so.*
%{_libdir}/libb10-util.so.*

%files dns
%{_bindir}/b10-dbutil
%{_mandir}/man8/b10-dbutil*
%{_bindir}/b10-loadzone
%{_mandir}/man8/b10-loadzone*
%{b10libexecdir}/b10-auth
%{_mandir}/man8/b10-auth*
%{b10libexecdir}/b10-ddns
%{_mandir}/man8/b10-ddns*
%{b10libexecdir}/b10-resolver
%{_mandir}/man8/b10-resolver*
%{b10libexecdir}/b10-xfrin
%{_mandir}/man8/b10-xfrin*
%{b10libexecdir}/b10-xfrout
%{_mandir}/man8/b10-xfrout*
%{b10libexecdir}/b10-zonemgr
%{_mandir}/man8/b10-zonemgr*
%dir %{b10libexecdir}/backends
%{b10libexecdir}/backends/*.so
%{b10datadir}/auth.spec
%{b10datadir}/ddns.spec
%{b10datadir}/xfrin.spec
%{b10datadir}/xfrout.spec
%{b10datadir}/zonemgr.spec
%{b10datadir}/resolver.spec
%{_libdir}/libb10-acl.so.*
%{_libdir}/libb10-asiodns.so.*
%{_libdir}/libb10-cache.so.*
%{_libdir}/libb10-datasrc.so.*
%{_libdir}/libb10-dnsacl.so.*
%{_libdir}/libb10-nsas.so.*
%{_libdir}/libb10-resolve.so.*
%{_libdir}/libb10-server-common.so.*
%{_libdir}/libb10-threads.so.*
%{_libdir}/libb10-xfr.so.*

%dir %{python3_sitearch}/isc/acl
%{python3_sitearch}/isc/acl/*.py*
%{python3_sitearch}/isc/acl/*.so
%{python3_sitearch}/isc/acl/__pycache__

%dir %{python3_sitearch}/isc/server_common
%{python3_sitearch}/isc/server_common/*.py*
%{python3_sitearch}/isc/server_common/__pycache__

%dir %{python3_sitearch}/isc/xfrin
%{python3_sitearch}/isc/xfrin/*.py*
%{python3_sitearch}/isc/xfrin/__pycache__

%dir %{python3_sitearch}/isc/notify
%{python3_sitearch}/isc/notify/*.py*
%{python3_sitearch}/isc/notify/__pycache__

%dir %{python3_sitearch}/isc/datasrc
%{python3_sitearch}/isc/datasrc/*.py*
%{python3_sitearch}/isc/datasrc/*.so
%{python3_sitearch}/isc/datasrc/__pycache__

%dir %{python3_sitearch}/isc/ddns
%{python3_sitearch}/isc/ddns/*.py*
%{python3_sitearch}/isc/ddns/__pycache__

%dir %{python3_sitearch}/isc/dns
%{python3_sitearch}/isc/dns/*.py*
%{python3_sitearch}/isc/dns/__pycache__

%files dhcp
%{_bindir}/perfdhcp
%{b10libexecdir}/b10-dhcp4
%{_mandir}/man8/b10-dhcp4*
%{b10libexecdir}/b10-dhcp6
%{_mandir}/man8/b10-dhcp6*
%{b10datadir}/dhcp4.spec
%{b10datadir}/dhcp6.spec
%{b10datadir}/dhcpdb_create.mysql
%{_libdir}/libb10-dhcp++.so.*
%{_libdir}/libb10-dhcpsrv.so.*

%changelog
* Fri Jun 07 2013 Tomas Hozza <thozza@redhat.com> - 1.0.0-4
- rebuild against new log4cplus

* Tue Jun 04 2013 Tomas Hozza <thozza@redhat.com> - 1.0.0-3
- create /run/bind10 directory for bind10 PID file
- set GID bit on /var/bind10 directory to prevent permission issues (#970207)

* Tue Mar 26 2013 Adam Tkac <atkac redhat com> - 1.0.0-2
- rebuild for ARM64 support

* Mon Feb 25 2013 Adam Tkac <atkac redhat com> - 1.0.0-1
- update to 1.0.0

* Wed Feb 20 2013 Adam Tkac <atkac redhat com> - 1.0.0-0.5.rc
- update to 1.0.0-rc
- bind10-rpath.patch has been merged

* Wed Feb 20 2013 Adam Tkac <atkac redhat com> - 1.0.0-0.4.beta
- make bind10 compilable against boost 1.53.0

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.0-0.3.beta
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Feb 08 2013 Adam Tkac <atkac redhat com> 1.0.0-0.2.beta
- minor packaging review related fixes

* Mon Jan 28 2013 Adam Tkac <atkac redhat com> 1.0.0-0.1.beta
- initial package
